# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Perform diffs on files and record sets
Name:		perl-Text-Diff
Version:	1.45
Release:	6.%{__distinit}%{__distvers}
License:	GPLv2+ or Artistic
URL:		https://metacpan.org/release/Text-Diff
Source0:	https://cpan.metacpan.org/modules/by-module/Text/Text-Diff-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Algorithm::Diff) >= 1.19
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(Test)
BuildRequires:	perl(Test::More)
# Optional Tests
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Test::CPAN::Meta) >= 0.12
# Test::MinimumVersion → Perl::MinimumVersion → Perl::Critic →
#   PPIx::Regexp/Exception::Class → Test::Kwalitee → Module::CPANTS::Analyse →
#   Archive::Any → Archive::Tar → Text::Diff
BuildRequires:	perl(Test::MinimumVersion) >= 0.008
BuildRequires:	perl(Test::Pod) >= 1.26
%endif
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
diff() provides a basic set of services akin to the GNU diff utility. It is not
anywhere near as feature complete as GNU diff, but it is better integrated with
Perl and available on all platforms. It is often faster than shelling out to a
system's diff executable for small files, and generally slower on larger files.

Relies on Algorithm::Diff for, well, the algorithm. This may not produce the
same exact diff as a system's local diff executable, but it will be a valid
diff and comprehensible by patch. We haven't seen any differences between
Algorithm::Diff's logic and GNU diff's, but we have not examined them to make
sure they are indeed identical.

%prep
%setup -q -n Text-Diff-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test AUTOMATED_TESTING=1

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README
%{perl_vendorlib}/Text/
%{_mandir}/man3/Text::Diff.3*
%{_mandir}/man3/Text::Diff::Config.3*
%{_mandir}/man3/Text::Diff::Table.3*

%changelog
* Thu May 30 2019 Paul Howarth <paul@city-fan.org> - 1.45-6
- Switch upstream from search.cpan.org to metacpan.org
- Avoid all optional build requirements when bootstrapping

* Thu Aug 17 2017 Paul Howarth <paul@city-fan.org> - 1.45-1
- Update to 1.45
  - Typo fixed in documentation (CPAN RT#112564)
  - Documentation improvements (GH#2)
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Tue Oct 11 2016 Paul Howarth <paul@city-fan.org> - 1.44-2
- BR: perl-generators where available
- Simplify find command using -delete

* Sat Feb 27 2016 Paul Howarth <paul@city-fan.org> - 1.44-1
- Update to 1.44
  - Fixed the handling of text without a trailing newline: this module now adds
    the same text that the diff tool does, "\n\\ No newline at end of file\n";
    previously this module simply produced broken diffs when one or both files
    had no trailing newline (GH#1)

* Wed Sep  2 2015 Paul Howarth <paul@city-fan.org> - 1.43-1
- Update to 1.43
  - Got rid of the "Redundant argument in sprintf" warnings from
    Text:Diff::Table on Perl 5.021+ (CPAN RT#100505, CPAN RT#106602)
  - Metadata and doc now refer to NEILB's repo rather than OVID's

* Thu Aug 20 2015 Paul Howarth <paul@city-fan.org> - 1.42-1
- Update to 1.42
  - Updated all modules to "use warnings", and use "our ...", so bumped minimum
    perl version to 5.006 and added MIN_PERL_VERSION to Makefile.PL
  - If a file doesn't exist, you'd get a warning about trying to read a closed
    filehandle; now we croak (CPAN RT#73505)
  - Blank line needed for =head1 OPTIONS to format properly (CPAN RT#94895)
  - The '>' character needed escaping inside pod formatting code
    (CPAN RT#51612)
  - Fixed syntax error in SYNOPSIS of Text::Diff::Table (CPAN RT#25283)
  - Updated FSF postal address in LICENSE (CPAN RT#101553)
  - Added SEE ALSO section to doc, with links to a bunch of Diff modules
  - Added link to github repository in the doc
  - Deleted META.yml from the repo; EUMM will generate it for us
  - Reformatted Changes file as per CPAN::Changes::Spec
  - Added TODO.md, with two further things I can see need doing
  - Removed all tab characters from source
  - Fixed pod link that was referring to the wrong place (CPAN RT#106150)
- This release by NEILB → update source URL
- Classify buildreqs by usage
- Add workaround for redundant argument in sprintf warning (CPAN RT#100505)

* Mon Sep  1 2014 Paul Howarth <paul@city-fan.org> - 1.41-9
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 1.41-5
- Perl 5.16 post-bootstrap rebuild

* Mon Jul  2 2012 Paul Howarth <paul@city-fan.org> - 1.41-4
- BR: perl(Carp), perl(constant), perl(Data::Dumper), perl(Exporter),
  perl(IO::File) and perl(Test)

* Tue Mar 13 2012 Paul Howarth <paul@city-fan.org> - 1.41-3
- Don't BR: perl(Test::MinimumVersion) if we're bootstrapping
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Jul  7 2011 Paul Howarth <paul@city-fan.org> - 1.41-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Apr 18 2011 Paul Howarth <paul@city-fan.org> - 1.41-1
- Update to 1.41:
  - Added DIFF_OUTPUT_UNICODE env variable to allow outputting unicode
    characters
  - Added Text::Diff::Config to MANIFEST
- This release by OVID -> update source URL
- Nobody else likes macros for commands

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 1.37-4
- Rebuild for perl 5.12.1 in Rawhide

* Fri May 28 2010 Paul Howarth <paul@city-fan.org> - 1.37-3
- Fix dist tag for RHEL-6 Beta

* Fri Feb 12 2010 Paul Howarth <paul@city-fan.org> - 1.37-2
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Fri Jul 17 2009 Paul Howarth <paul@city-fan.org> - 1.37-1
- Update to 1.37 (clean up and add author tests)
- Clarify license as GPL version 2 or later, or Artistic
- Add doc files README and LICENSE
- New upstream maintainer -> new source URL
- Enable AUTOMATED_TESTING and add buildreqs for test suite:
  - perl(Test::CPAN::Meta) >= 0.12
  - perl(Test::MinimumVersion) >= 0.008
  - perl(Test::More)
  - perl(Test::Pod) >= 1.26
- Define RPM macros in global scope

* Wed Jun  6 2007 Paul Howarth <paul@city-fan.org> - 0.35-4
- Fix dist tag for Fedora 7 onwards
- Fix argument order for find with -depth
- BuildRequire perl(ExtUtils::MakeMaker)

* Fri Sep  1 2006 Paul Howarth <paul@city-fan.org> - 0.35-3
- Simplify distribution-detection code
- Don't define %%perl_vendorarch in noarch package
- Remove %%__perl_version macro, used only once
- Remove %%__perl_package macro, used only twice
- Don't use macros in build-time command paths, hardcode them instead
- Remove buildroot unconditionally in %%clean and %%install
- Don't set up compiler optimization flags in noarch package
- Use search.cpan.org URLs
- Define %%{__id_u} in a more portable way
- Fix directory ownership

* Thu May 26 2005 Paul Howarth <paul@city-fan.org> - 0.35-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Remove MANIFEST from %%doc

* Mon May 10 2004 Paul Howarth <paul@city-fan.org> - 0.35-1
- Initial build
